gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [gnunet] 42/45: handles, not handlers


From: gnunet
Subject: [GNUnet-SVN] [gnunet] 42/45: handles, not handlers
Date: Sun, 31 Dec 2017 00:37:29 +0100

This is an automated email from the git hooks/post-receive script.

lurchi pushed a commit to branch master
in repository gnunet.

commit 0cdad12df4123d4b30603d552f1e3c1effab5015
Author: lurchi <address@hidden>
AuthorDate: Mon Sep 4 12:40:53 2017 +0200

    handles, not handlers
---
 src/util/scheduler.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/util/scheduler.c b/src/util/scheduler.c
index a2eaab9aa..72f2b7230 100644
--- a/src/util/scheduler.c
+++ b/src/util/scheduler.c
@@ -147,11 +147,11 @@ struct GNUNET_SCHEDULER_Task
   unsigned int ready_fds_len;
 
   /**
    * Do we own the network and file handlers referenced by the FdInfo
    * structs in the fds array. This will only be GNUNET_YES if the
    * task was created by the #GNUNET_SCHEDULER_add_select function.
    */
-  int own_handlers;
+  int own_handles;
 
   /**
    * Absolute timeout value for the task, or
@@ -539,7 +539,7 @@ destroy_task (struct GNUNET_SCHEDULER_Task *t)
        "destroying task %p\n",
        t);
 
-  if (GNUNET_YES == t->own_handlers)
+  if (GNUNET_YES == t->own_handles)
   {
     for (i = 0; i != t->fds_len; ++i)
     {
@@ -1762,7 +1762,7 @@ GNUNET_SCHEDULER_add_select (enum 
GNUNET_SCHEDULER_Priority prio,
   t->callback_cls = task_cls;
   t->read_fd = -1;
   t->write_fd = -1;
-  t->own_handlers = GNUNET_YES;
+  t->own_handles = GNUNET_YES;
   read_nhandles = NULL;
   write_nhandles = NULL;
   read_fhandles = NULL;
@@ -147,11 +147,11 @@ struct GNUNET_SCHEDULER_Task
 
   /**
-   * Do we own the network and file handlers referenced by the FdInfo
+   * Do we own the network and file handles referenced by the FdInfo
    * structs in the fds array. This will only be GNUNET_YES if the
    * task was created by the #GNUNET_SCHEDULER_add_select function.

-- 
To stop receiving notification emails like this one, please contact
address@hidden



reply via email to

[Prev in Thread] Current Thread [Next in Thread]